<?xml version="1.0" ?><!DOCTYPE TS><TS language="th" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>มีชีวิตนอกเบราว์เซอร์!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>เวอร์ชั่น %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>ถูกลงทะเบียนสู่: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 เป็นโปรแกรมฟรีแต่การพัฒนามันจะต้องใช้เวลาเป็นอย่างมาก</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>กรุณา &lt;a href=&apos;%1&apos;&gt;บริจาค&lt;/a&gt; เพื่อสนับสนุนการพัฒนาโปรแกรม %2 ต่อไป</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>แปล %1 สุ่ภาษาของคุณโดยใช้ %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>ออกแบบไอคอนโดย %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>ปล่อยเผยแพร่ภายใต้ &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;ปิด</translation>
    </message>
    <message>
        <source>About</source>
        <translation>เกี่ยวกับ</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>กรอกรายละเอียดใบอนุญาตของคุณ</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;อีเมล:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;รหัส:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>โปรดซื้อใบอนุญาต %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>ชุดทดลองใช้หมดอายุแล้ว</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>เวอร์ชั่นเต็มจะอนุญาตให้คุณรับชมวิดีโอโดยไม่ถูกขัดจังหวะ</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>ปราศจากใบอนุญาต แอปพลิเคชั่นจะหมดอายุใน %1 วัน</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>ด้วยการซื้อเวอร์ชั่นเต็ม คุณยังได้สนับสนุนการทำงานหนักที่ฉันใช้ในการสร้าง %1</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>ใช้ชุดทดลอง</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>กรอกใบอนุญาต</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>ซื้อใบอนุญาต</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>โดย %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>วิดีโอทั้งหมด</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>วิดีโอที่ไม่ได้รับชม</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>ชื่อ</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>ถูกอัพเดตล่าสุด</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>ถูกเพิ่มล่าสุด</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>ถูกรับชมล่าสุด</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>ถูกรับชมมากที่สุด</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>เรียงตาม</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>หมายเหตุทั้งหมดว่ารับชมแล้ว</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>แสดงอัพเดต</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>คุณไม่มีการสมัครติดตาม ใช้สัญลักษณ์ดาวเพื่อสมัครติดตามช่อง</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>วิดีโอทั้งหมด</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>วิดีโอที่ไม่ได้รับชม</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>หมายเหตุว่ารับชมแล้ว</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>เลิกสมัครติดตาม</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>ไม่มีการสมัครติดตามที่อัพเดต ณ เวลานี้</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>ดู %1 ครั้ง </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bytes/sec</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/sec</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/sec</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>วินาที</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>นาที</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 ที่เหลืออยู่</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 ถูกดาวน์โหลดใน %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>ดาวน์โหลดเสร็จสิ้น</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>เปลี่ยนที่ตั้ง...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>เลือกที่ตั้งการดาวน์โหลด</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>ที่ตั้งการดาวน์โหลดถูกเปลี่ยน</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>การดาวน์โหลดปัจจุบันจะยังคงไปสู่ที่ตั้งก่อนหน้านี้</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>กำลังดาวน์โหลดสู่: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>ดาวน์โหลด</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reinstall</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>เล่น</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>พัก</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>เล่น/พัก</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>หยุด</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>หยุดเล่นหลังจากแทร็คปัจจุบัน</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>แทร็คต่อไป</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>แทร็คก่อนหน้า</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>เพิ่มความดัง</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>ลดความดัง</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>เงียบ</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>หาเดินหน้า</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>หาย้อนกลับ</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>ค้นหา</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>ค้นหาวิดีโอและช่องโดยใช้คำสำคัญ</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>เรียกดู</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>เรียกดูวิดีโอตามหมวดหมู่</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>การสมัครติดตาม</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>การสมัครติดตามช่อง</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>ทำตัวเองให้สบาย</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>ผิดพลาด</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;หยุด</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>หยุดเล่นและกลับสู่มุมมองการค้นหา</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>&amp;ก่อนหน้า</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>กลับไปที่แทร็คก่อนหน้า</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;ข้าม</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>ข้ามสู่วิดีโอถัดไปไป</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>เ&amp;ล่น</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>เล่นต่อจากเดิม</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>เ&amp;ต็มจอ</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>ทำให้เต็มจอ</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>โหมด&amp;กะทัดรัด</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>ซ่อนบัญชีการเล่นและแถบเครื่องมือ</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>เ&amp;ปิดหน้า Youtube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>ไปที่หน้าวิดีโอ YouTube และพักการเล่น</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>คัดลอก&amp;ลิงค์ Youtube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>คัดลอกลิงค์วิดีโอ YouTube ในปัจจุบันไปยังคลิปบอร์ด</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>คัดลอก &amp;URL ของกระแสวิดีโอ</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>คัดลอก URL กระแสวิดีโอปัจจุบันสู่คลิปบอร์ด</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>ค้นหา&amp;ตอนของวิดีโอ</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>ค้นหาตอนอื่นๆของวิดีโอ โดยหวังตามลำดับที่ถูกต้อง</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;ลบออก</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>ลบวิดีโอที่เลือกออกจากบัญชีการเล่น</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>ย้าย&amp;ขึ้น</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>เลื่อนวิดีโอที่เลือกขึ้นบน ในบัญชีการเล่น</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>ย้าย&amp;ลง</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>เลื่อนวิดีโอที่เลือกลงล่าง ในบัญชีการเล่น</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;ล้างการค้นหาเมื่อเร็วๆนี้</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>การล้างประวัติการค้นหา ไม่สามารถเลิกทำได้</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;ออก</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>ลาก่อน</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>เ&amp;ว็บไซต์</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 บนเว็บ</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>ทำการ&amp;บริจาค</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>กรุณาสนับสนุนการพัฒนาอย่างต่อเนื่องของ %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;เกี่ยวกับ</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>ข้อมูลเกี่ยวกับ %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>ค้นหา</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>เงียบเสียง</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>เ&amp;ริ่มการเล่นด้วยตนเอง</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>เริ่มการเล่นวิดีโอด้วยตนเอง</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;ดาวน์โหลด</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>แสดงข้อมูลของวิดีโอที่ดาวน์โหลด</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;ดาวน์โหลด</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>ดาวน์โหลดวิดีโอปัจจุบัน</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>&amp;ถ่ายภาพ</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;สมัครติดตามช่อง</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>แชร์วิดีโอปัจจุบันโดยใช้ %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;อีเมล</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>อีเมล</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;ปิด</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;วางอยู่บนสุด</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;หยุดหลังจากวิดีโอนี้</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;รายงานปัญหา...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;ค้นหาโดยละเอียด...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>เพิ่มเติม...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>&amp;วิดีโอที่เกี่ยวข้อง</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>รับชมวิดีโอที่เกี่ยวข้องกับรายการปัจจุบัน</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>เปิดในเ&amp;บราว์เซอร์...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;ชอบ %1 มั้ย? ให้คะแนนมันหน่อย!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>ซื้อ %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;แอปพลิเคชั่น</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>การเ&amp;ล่น</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;บัญชีการเล่น</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;วิดีโอ</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>แ&amp;บ่งปัน</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;มุมมอง</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;ช่วยเหลือ</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>กด %1 เพื่อเพิ่มเสียง กด %2 เพื่อลดเสียง</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>เลือกที่ตั้งเนื้อหาของคุณ</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>กำลังเปิด %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>คุณจะออกจาก %1 โดยที่การดาวน์โหลดกำลังดำเนินอยู่หรือ?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>ถ้าคุณปิด %1 ตอนนี้ การดาวน์โหลดจะถูกยกเลิก</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>ปิดและยกเลิกการดาวน์โหลด</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>รอให้ดาวน์โหลดเสร็จ</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>ผิดพลาด: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;พัก</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>พักการเล่น</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>ออกจากแบบเ&amp;ต็มจอ</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>เวลาที่เหลือ: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>ความดังเสียงที่ %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>เสียงถูกปิด</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>เสียงถูกเปิด</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>ใช้วิดีโอความละเอียดสูงสุด %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>ความเป็นส่วนตัวของคุณขณะนี้ปลอดภัย</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>ดาวน์โหลดเสร็จ</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 เวอร์ชั่น %2 ตอนนี้มีพร้อมใช้</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>แจ้งฉันภายหลัง</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>อัพเดต</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>ตอนนี้คุณสามารถวางลิงค์ของ YouTube ในแอปพลิเคชั่นอื่นได้</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>ตอนนี้คุณสามารถวาง URL ของกระแสวิดีโอลงในแอปพลิเคชั่นอื่นได้</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>ลิงค์จะใช้ได้ในระยะเวลาที่จำกัดเท่านั้น</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>กำลังดาวน์โหลด %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>จาก</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>ตอน</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>ภาค</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>ถูกส่งจาก %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>เลิกสมัครติดตามจาก %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>สมัครติดตามสู่ %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>เวอร์ชั่นใหม่ของ %1 มีพร้อมแล้ว!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 ตอนนี้มีพร้อมแล้ว คุณมี %3</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>คุณอยากจะดาวน์โหลดตอนนี้หรือไม่?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>ข้ามเวอร์ชั่นนี้</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>แจ้งฉันภายหลัง</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>ติดตั้งอัพเดต</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>วาง</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 ของ %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>กำลังเตรียม</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>ล้มเหลว</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>เสร็จสมบูรณ์</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>ถูกหยุด</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>หยุดการดาวน์โหลด</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>แสดงใน %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>เปิดโฟลเดอร์แม่</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>เริ่มดาวน์โหลดใหม่</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>แสดง %1 เพิ่มเติม</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>ไม่มีวิดีโอ</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>ไม่มีวิดีโอเพิ่มเติม</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>เรียงตาม</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>ความเกี่ยวข้อง</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>วันที่</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>จำนวนการดู</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>คะแนน</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>เวลาใดๆ</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>วันนี้</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 วัน</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 วัน</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>ระยะเวลา</translation>
    </message>
    <message>
        <source>All</source>
        <translation>ทั้งหมด</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>สั้น</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>ปานกลาง</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>ยาว</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>น้อยกว่า 4 นาที</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>ระหว่าง 4 ถึง 20 นาที</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>ยาวกว่า 20 นาที</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>คุณภาพ</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>ความละเอียดสูง</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p หรือสูงกว่า</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>เสร็จแล้ว</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>เสร็จแล้ว</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>ค้นหา</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>ยินดีต้อนรับสู่ &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>เพื่อเริ่มรับชมวิดีโอ</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>คำสำคัญ</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>ตกลง</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>คำสำคัญเมื่อเร็วๆนี้</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>ช่องเมื่อเร็วๆนี้</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>ซื้อเวอร์ชั่นเต็ม</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;กลับ</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>เดินหน้าสู่ %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>กลับสู่ %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>ค้นหาโดยละเอียด</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>หรือคุณหมายถึง: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>เปลี่ยนที่บันทึก</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>ภาพถ่ายถูกบันทึกสู่ %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>ที่ตั้งของภาพถ่ายถูกเปลี่ยน</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>ยอดนิยม</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>กำลังดาวน์โหลดอัพเดต...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>แอลจีเรีย</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>อาร์เจนติน่า</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>ออสเตรเลีย</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>เบลเยี่ยม</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>บราซิล</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>แคนาดา</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>ชิลี</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>โคลอมเบีย</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>เชค, สาธารณรัฐ</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>อียิปต์</translation>
    </message>
    <message>
        <source>France</source>
        <translation>ฝรั่งเศส</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>เยอรมนี</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>กาน่า</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>กรีซ</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>ฮ่องกง</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>ฮังการี่</translation>
    </message>
    <message>
        <source>India</source>
        <translation>อินเดีย</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>อินโดนีเซีย</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>ไอร์แลนด์</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>อิสราเอล</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>อิตาลี่</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>ญี่ปุ่น</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>จอร์แดน</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>เคนย่า</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>มาเลเซีย</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>เม็กซิโก</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>โมร็อกโก</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>เนเธอร์แลนด์</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>นิวซีแลนด์</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>ไนจีเรีย</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>เปรู</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>ฟิลิปปินส์</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>โปแลนด์</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>รัสเซีย</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>ซาอุดิอาระเบีย</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>สิงคโปร์</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>อาฟริกาใต้</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>เกาหลีใต้</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>สเปน</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>สวีเดน</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>ไต้หวัน</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>ตูนิเซีย</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>ตุรกี</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>ยูกันดา</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>สหรัฐอาหรับเอมิเรสต์</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>สหราชอาณาจักร</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>เยเมน</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>ทั่วโลก</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>ไม่สามารถรับกระแสวิดีโอของ %1</translation>
    </message>
</context>
</TS>